@@ -1,5 +1,5 @@
 package Net::FreeIPA::RPC;
-$Net::FreeIPA::RPC::VERSION = '3.0.0';
+$Net::FreeIPA::RPC::VERSION = '3.0.1';
 use strict;
 use warnings;
 
@@ -301,7 +301,7 @@ sub rpc
         $response->set_result($opts{result_path});
 
         if ($error) {
-            my @noerrors = grep {$error == $_} @{$opts{noerror} || []};
+            my @noerrors = grep {defined($_) && $error == $_} @{$opts{noerror} || []};
 
             my $error_method = @noerrors ? 'debug' : 'error';
 
